(Hopefully complete) list of people who contributed to this project:

  * Sebastian Łopieński
  * Piotr Lizończyk
  * Vincent Brillaut
  * Farzaneh Moghaddam
  * Antonio Perez Perez
  * Dame Jovanoski
  
Special thanks to Elbert Alias, the author of Wappalyzer.